# Lance Namespace

**Lance Namespace** is an open specification on top of the storage-based Lance data format
to standardize access to a collection of Lance tables (a.k.a. Lance datasets).
It describes how a metadata service like Apache Hive MetaStore (HMS),
Apache Gravitino, Unity Catalog, etc. should store and use Lance tables, 
as well as how ML/AI tools and analytics compute engines should integrate with Lance tables.

For more details, please visit the [documentation website](https://lancedb.github.io/lance/format/namespace).

For development setup and contribution guidelines, please see [CONTRIBUTING.md](CONTRIBUTING.md).